@@ -2,13 +2,13 @@ import fastai
 from fastai  import *
 from fastai.vision import *
 import sys
+import os
 
 warnings.filterwarnings("ignore")
 
 def Determine(path):
-    prefix=sys.prefix
-    final=prefix + '\\Lib\\site-packages\\detect_mask'
-    learn=load_learner(final)
+    path=os.path.dirname(os.path.abspath(__file__))
+    learn=load_learner(r'{}'.format(path))
     img=open_image(path)
     k=learn.predict(img)[1]
     if k==1:
